@@ -31,11 +31,10 @@ T = TypeVar("T")
 Maybe = Union[T, NotPassed]
 
 
-COMPOSITION_KEYWORDS = ("anyOf", "oneOf", "allOf")
+COMPOSITION_KEYWORDS = ("anyOf", "oneOf", "allOf", "not")
 
 
 UNSUPPORTED_SCHEMA_KEYWORDS = {
-    "additionalItems",
     "const",
     "contains",
     "$defs",
@@ -46,8 +45,6 @@ UNSUPPORTED_SCHEMA_KEYWORDS = {
     "else",
     "maxProperties",
     "minProperties",
-    "not",
-    "patternProperties",
     "propertyNames",
     "unevaluatedItems",
     "unevaluatedProperties",
