@@ -1,11 +1,11 @@
-from typing import Any, Iterable, List, NamedTuple, Optional, Set, TypeVar
+from typing import Any, List, NamedTuple, Optional, TypeVar
 from typing_extensions import Literal
 
+from statham.dsl.constants import NotPassed
 from statham.dsl.elements.base import Element
+from statham.dsl.helpers import remove_duplicates
 from statham.dsl.exceptions import ValidationError
 from statham.dsl.property import _Property
-from statham.dsl.constants import NotPassed
-
 
 # TODO: if, then, else
 
@@ -14,17 +14,30 @@ Mode = Literal["anyOf", "oneOf", "allOf"]  # pylint: disable=invalid-name
 T = TypeVar("T")
 
 
-def _dedupe(seq: Iterable[T]) -> List[T]:
-    seen: Set[T] = set()
-    seen_add = seen.add
-    return [x for x in seq if not (x in seen or seen_add(x))]
+class Not(Element[T]):
+    """JSONSchema "not" element.
+
+    Element fails to validate if enclosed schema validates.
+    """
+
+    def __init__(self, element: Element, default: Any = NotPassed()):
+        self.element = element
+        super().__init__(default=default)
+
+    def construct(self, value: Any, property_: _Property):
+        try:
+            _ = self.element(value, property_)
+        except (TypeError, ValidationError):
+            return value
+        raise ValidationError.from_validator(
+            property_, value, f"Must not match {self.element}."
+        )
 
 
 class CompositionElement(Element):
     """Composition Base Element.
 
     The "oneOf", "anyOf" and "allOf" elements share the same interface.
-    # TODO: not
     """
 
     mode: Mode
@@ -38,7 +51,9 @@ class CompositionElement(Element):
 
     @property
     def annotation(self):
-        annotations = _dedupe(elem.annotation for elem in self.elements)
+        annotations = remove_duplicates(
+            elem.annotation for elem in self.elements
+        )
         if len(annotations) == 1:
             return annotations[0]
         if "Any" in annotations:
