@@ -1,6 +1,5 @@
-from typing import Any, Optional
+from typing import Any
 
-from statham.dsl.constants import NotPassed
 from statham.dsl.exceptions import ValidationError
 from statham.dsl.validation.base import Validator
 
@@ -17,24 +16,19 @@ class Required(Validator):
 
 class AdditionalProperties(Validator):
     types = (dict,)
-    keywords = ("properties", "additionalProperties")
+    keywords = ("__properties__",)
     message = "Must not contain unspecified properties. Accepts: {properties}"
 
-    @classmethod
-    def from_element(cls, element) -> Optional["AdditionalProperties"]:
-        params = list(
-            getattr(element, keyword, None) for keyword in cls.keywords
+    def error_message(self):
+        return self.message.format(
+            properties=set(self.params["__properties__"])
         )
-        if None in params:
-            return None
-        params[0] = set(params[0] or {})
-        params[1] = bool(
-            True if isinstance(params[1], NotPassed) else params[1]
-        )
-        return cls(*params)
 
     def validate(self, value: Any):
-        if self.params["additionalProperties"]:
+        if self.params["__properties__"].additional:
             return
-        if set(value) - self.params["properties"]:
+        bad_properties = {
+            key for key in value if key not in self.params["__properties__"]
+        }
+        if bad_properties:
             raise ValidationError
